``pyramid_tm``
==============

.. image:: https://github.com/Pylons/pyramid_tm/actions/workflows/ci-tests.yml/badge.svg?branch=main
    :target: https://github.com/Pylons/pyramid_tm/actions/workflows/ci-tests.yml?query=branch%3Amain
    :alt: main CI Status


.. image:: https://readthedocs.org/projects/pyramid-tm/badge/?version=latest
        :target: https://docs.pylonsproject.org/projects/pyramid-tm/en/latest/
        :alt: Documentation Status

``pyramid_tm`` is a package which allows Pyramid requests to join
the active transaction as provided by the `transaction
<https://pypi.org/project/transaction/>`_ package.

See `https://docs.pylonsproject.org/projects/pyramid_tm/en/latest/
<https://docs.pylonsproject.org/projects/pyramid_tm/en/latest/>`_ 
or ``docs/index.rst`` in this distribution for detailed
documentation.
